==> mars-1.1.2.tar.gz: mars-1.1.2/tests/TPF/TPF_50_002/mpu1.c <==
/*
 * Copyright 2008 Sony Computer Entertainment Inc.
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <mars/task.h>
#include <mars_test.h>
#include "common.h"

int mars_task_main(const struct mars_task_args *task_args)
{
	int ret, i, j, semaphore_count;
	uint32_t start, end;
	static struct test_task_args_st args ALIGN128;
	static uint32_t acquire_ticks[TEST1_ELEMENT_COUNT] ALIGN128;

	mfc_get(&args, task_args->type.u64[0],
		sizeof(struct test_task_args_st), 0, 0, 0);
	mfc_write_tag_mask(1);
	mfc_read_tag_status_all();

	semaphore_count = mars_test_int32_get(args.semaphore_count_ea);

	for (i = 0; i < TEST1_ELEMENT_COUNT; i++) {
		ret = mars_task_barrier_notify(args.barrier_ea);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);
		ret = mars_task_barrier_wait(args.barrier_ea);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

		start = mars_task_get_ticks();
		for (j = 0; j < semaphore_count; j++) {
			ret = mars_task_semaphore_acquire(args.semaphore_ea);
			MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);
		}

		end = mars_task_get_ticks();

		ret = mars_task_barrier_notify(args.barrier_ea);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);
		ret = mars_task_barrier_wait(args.barrier_ea);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

		acquire_ticks[i] = (end - start) / semaphore_count;
	}

	mfc_put(acquire_ticks, args.ticks1_ea, sizeof(acquire_ticks), 0, 0, 0);
	mfc_write_tag_mask(1);
	mfc_read_tag_status_all();

	return 0;
}

==> mars-1.1.3.tar.gz: mars-1.1.3/tests/TPF/TPF_60_004/mpu1.c <==
/*
 * Copyright 2008 Sony Computer Entertainment Inc.
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

#include <mars/task.h>
#include <mars_test.h>
#include <common.h>

int mars_task_main(const struct mars_task_args *task_args)
{
	int ret, i;
	static struct test_task_args_st args ALIGN128;
	static uint32_t start1_ticks[TEST1_ELEMENT_COUNT] ALIGN128;
	static uint32_t start2_ticks[TEST1_ELEMENT_COUNT] ALIGN128;

	mfc_get(&args, task_args->type.u64[0], sizeof(struct test_task_args_st),
		0, 0, 0);
	mfc_write_tag_mask(1);
	mfc_read_tag_status_all();

	for (i = 0; i < TEST1_ELEMENT_COUNT; i++) {
		ret = mars_task_barrier_notify(args.barrier_ea);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);
		ret = mars_task_barrier_wait(args.barrier_ea);
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);

		mars_test_usleep(args.tb_freq, DELAY); /*give wait task time to block */

		start1_ticks[i] = mars_task_get_ticks();
		ret = mars_task_signal_send(&args.task_id);
		start2_ticks[i] = mars_task_get_ticks();
		MARS_TEST_ASSERT_ERROR(ret, MARS_SUCCESS);
	}

	mfc_put(start1_ticks, args.ticks1_ea, TEST1_ELEMENT_COUNT * 4, 0, 0, 0);
	mfc_write_tag_mask(1);
	mfc_read_tag_status_all();

	mfc_put(start2_ticks, args.ticks2_ea, TEST1_ELEMENT_COUNT * 4, 0, 0, 0);
	mfc_write_tag_mask(1);
	mfc_read_tag_status_all();
	return 0;
}
